---
name: Bug report
about: Create a report to help us improve
title: "[Bug]"
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Screenshots/Recording**
If applicable, add screenshots or recordings to help explain your problem.
This is especially helpful if your issue is related to some "dynamic" component.

**Environment:**

1. Distribution: Use the output from `cat /etc/os-release`:
```
<paste output>
```

2. `isd` version: Open `isd`, open the command palette and run `Show the version`

```
<isd version>
```

3. Provide the `systemd` version via `systemctl --version`

```
<paste systemctl output
```

4. Provide the used installation method

- [ ] AppImage
- [ ] nix
- [ ] uv
- [ ] Other
